@@ -28,7 +28,7 @@ from async_upnp_client.ssdp import SSDP_MX, determine_source_target, udn_from_he
 from async_upnp_client.utils import CaseInsensitiveDict
 
 _LOGGER = logging.getLogger(__name__)
-CACHE_CONTROL_RE = re.compile(r"max-age\s*=\s*(\d+)")
+CACHE_CONTROL_RE = re.compile(r"max-age\s*=\s*(\d+)", re.IGNORECASE)
 DEFAULT_MAX_AGE = timedelta(seconds=900)
 IGNORED_HEADERS = {
     "date",
@@ -260,10 +260,10 @@ class SsdpDeviceTracker(AbstractAsyncContextManager):
     """
     Device tracker.
 
-    Tracks SsdpDevices seen by the SsdpListener. Can be shared between SsdpListeners.
+    Tracks `SsdpDevices` seen by the `SsdpListener`. Can be shared between `SsdpListeners`.
 
-    This uses a asyncio.Lock to prevent simulatinous device updates when the SsdpDeviceTracker
-    is shared between SsdpListeners (e.g., for simultaneous IPv4 and IPv6 handling
+    This uses a `asyncio.Lock` to prevent simulatinous device updates when the `SsdpDeviceTracker`
+    is shared between `SsdpListeners` (e.g., for simultaneous IPv4 and IPv6 handling
     on the same network.)
     """
 
